@@ -1,9 +1,11 @@
 import tempfile
 import time
+from typing import Any, cast
 
 import pytest
+from requests.adapters import HTTPAdapter
 
-from garth.auth_tokens import OAuth2Token
+from garth.auth_tokens import OAuth1Token, OAuth2Token
 from garth.exc import GarthHTTPError
 from garth.http import Client
 
@@ -60,46 +62,60 @@ def test_configure_timeout(client: Client):
 
 def test_configure_retry(client: Client):
     assert client.retries == 3
-    assert client.sess.adapters["https://"].max_retries.total == client.retries
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.max_retries.total == client.retries
+
     client.configure(retries=99)
     assert client.retries == 99
-    assert client.sess.adapters["https://"].max_retries.total == 99
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.max_retries.total == 99
 
 
 def test_configure_status_forcelist(client: Client):
     assert client.status_forcelist == (408, 429, 500, 502, 503, 504)
-    assert (
-        client.sess.adapters["https://"].max_retries.status_forcelist
-        == client.status_forcelist
-    )
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.max_retries.status_forcelist == client.status_forcelist
+
     client.configure(status_forcelist=(200, 201, 202))
     assert client.status_forcelist == (200, 201, 202)
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.max_retries.status_forcelist == client.status_forcelist
 
 
-def test_backoff_factor(client: Client):
+def test_configure_backoff_factor(client: Client):
     assert client.backoff_factor == 0.5
-    assert (
-        client.sess.adapters["https://"].max_retries.backoff_factor
-        == client.backoff_factor
-    )
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.max_retries.backoff_factor == client.backoff_factor
+
     client.configure(backoff_factor=0.99)
     assert client.backoff_factor == 0.99
-    assert (
-        client.sess.adapters["https://"].max_retries.backoff_factor
-        == client.backoff_factor
-    )
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.max_retries.backoff_factor == client.backoff_factor
 
 
-def test_pool_connections(client: Client):
-    client.configure(
-        pool_connections=99,
-        pool_maxsize=99,
-    )
-    assert client.pool_connections == 99
+def test_configure_pool_maxsize(client: Client):
+    assert client.pool_maxsize == 10
+    client.configure(pool_maxsize=99)
     assert client.pool_maxsize == 99
     adapter = client.sess.adapters["https://"]
-    assert adapter._pool_connections == 99
-    assert adapter._pool_maxsize == 99
+    assert isinstance(adapter, HTTPAdapter)
+    assert adapter.poolmanager.connection_pool_kw["maxsize"] == 99
+
+
+def test_configure_pool_connections(client: Client):
+    client.configure(pool_connections=99)
+    assert client.pool_connections == 99
+    adapter = client.sess.adapters["https://"]
+    assert isinstance(adapter, HTTPAdapter)
+    assert getattr(adapter, "_pool_connections", None) == 99, (
+        "Pool connections not properly configured"
+    )
 
 
 @pytest.mark.vcr
@@ -128,15 +144,26 @@ def test_login_success_mfa(monkeypatch, client: Client):
 
 @pytest.mark.vcr
 def test_username(authed_client: Client):
-    assert authed_client._profile is None
+    assert authed_client._user_profile is None
     assert authed_client.username
-    assert authed_client._profile
+    assert authed_client._user_profile
+
+
+@pytest.mark.vcr
+def test_profile_alias(authed_client: Client):
+    assert authed_client._user_profile is None
+    profile = authed_client.profile
+    assert profile == authed_client.user_profile
+    assert authed_client._user_profile is not None
 
 
 @pytest.mark.vcr
 def test_connectapi(authed_client: Client):
-    stress = authed_client.connectapi(
-        "/usersummary-service/stats/stress/daily/2023-07-21/2023-07-21"
+    stress = cast(
+        list[dict[str, Any]],
+        authed_client.connectapi(
+            "/usersummary-service/stats/stress/daily/2023-07-21/2023-07-21"
+        ),
     )
     assert stress
     assert isinstance(stress, list)
@@ -168,7 +195,7 @@ def test_download(authed_client: Client):
         "/download-service/files/activity/11998957007"
     )
     assert downloaded
-    zip_magic_number = b"\x50\x4B\x03\x04"
+    zip_magic_number = b"\x50\x4b\x03\x04"
     assert downloaded[:4] == zip_magic_number
 
 
@@ -220,3 +247,31 @@ def test_put(authed_client: Client):
         json=data,
     )
     assert authed_client.connectapi(path)
+
+
+@pytest.mark.vcr
+def test_resume_login(client: Client):
+    result = client.login(
+        "example@example.com",
+        "correct_password",
+        return_on_mfa=True,
+    )
+
+    assert isinstance(result, tuple)
+    result_type, client_state = result
+
+    assert isinstance(client_state, dict)
+    assert result_type == "needs_mfa"
+    assert "csrf_token" in client_state
+    assert "signin_params" in client_state
+    assert "client" in client_state
+
+    code = "123456"  # obtain from custom login
+
+    # test resuming the login
+    oauth1, oauth2 = client.resume_login(client_state, code)
+
+    assert oauth1
+    assert isinstance(oauth1, OAuth1Token)
+    assert oauth2
+    assert isinstance(oauth2, OAuth2Token)
