@@ -42,6 +42,57 @@ def test_login_success_mfa(monkeypatch, client: Client):
     assert isinstance(oauth2, OAuth2Token)
 
 
+@pytest.mark.vcr
+def test_login_success_mfa_async(monkeypatch, client: Client):
+    def mock_input(_):
+        return "031174"
+
+    async def prompt_mfa():
+        return input("MFA code: ")
+
+    monkeypatch.setattr("builtins.input", mock_input)
+    oauth1, oauth2 = sso.login(
+        "user@example.com",
+        "correct_password",
+        client=client,
+        prompt_mfa=prompt_mfa,
+    )
+
+    assert oauth1
+    assert isinstance(oauth1, OAuth1Token)
+    assert oauth2
+    assert isinstance(oauth2, OAuth2Token)
+
+
+@pytest.mark.vcr
+def test_login_return_on_mfa(client: Client):
+    result = sso.login(
+        "user@example.com",
+        "correct_password",
+        client=client,
+        return_on_mfa=True,
+    )
+
+    assert isinstance(result, tuple)
+    result_type, client_state = result
+
+    assert isinstance(client_state, dict)
+    assert result_type == "needs_mfa"
+    assert "csrf_token" in client_state
+    assert "signin_params" in client_state
+    assert "client" in client_state
+
+    code = "123456"  # obtain from custom login
+
+    # test resuming the login
+    oauth1, oauth2 = sso.resume_login(client_state, code)
+
+    assert oauth1
+    assert isinstance(oauth1, OAuth1Token)
+    assert oauth2
+    assert isinstance(oauth2, OAuth2Token)
+
+
 def test_set_expirations(oauth2_token_dict: dict):
     token = sso.set_expirations(oauth2_token_dict)
     assert (
